==> vtk6-6.3.0-11-armv6h.pkg.tar.xz: vtk/vtkImageDataGeometryFilter.java <==
// java wrapper for vtkImageDataGeometryFilter object
//

package vtk;
import vtk.*;

public class vtkImageDataGeometryFilter extends vtkPolyDataAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetExtent_2(int id0[]);
  public void SetExtent(int id0[])
    { SetExtent_2(id0); }

  private native void SetExtent_3(int id0,int id1,int id2,int id3,int id4,int id5);
  public void SetExtent(int id0,int id1,int id2,int id3,int id4,int id5)
    { SetExtent_3(id0,id1,id2,id3,id4,id5); }

  private native void SetThresholdCells_4(int id0);
  public void SetThresholdCells(int id0)
    { SetThresholdCells_4(id0); }

  private native int GetThresholdCells_5();
  public int GetThresholdCells()
    { return GetThresholdCells_5(); }

  private native void ThresholdCellsOn_6();
  public void ThresholdCellsOn()
    { ThresholdCellsOn_6(); }

  private native void ThresholdCellsOff_7();
  public void ThresholdCellsOff()
    { ThresholdCellsOff_7(); }

  private native void SetThresholdValue_8(double id0);
  public void SetThresholdValue(double id0)
    { SetThresholdValue_8(id0); }

  private native double GetThresholdValue_9();
  public double GetThresholdValue()
    { return GetThresholdValue_9(); }

  private native void ThresholdValueOn_10();
  public void ThresholdValueOn()
    { ThresholdValueOn_10(); }

  private native void ThresholdValueOff_11();
  public void ThresholdValueOff()
    { ThresholdValueOff_11(); }

  private native void SetOutputTriangles_12(int id0);
  public void SetOutputTriangles(int id0)
    { SetOutputTriangles_12(id0); }

  private native int GetOutputTriangles_13();
  public int GetOutputTriangles()
    { return GetOutputTriangles_13(); }

  private native void OutputTrianglesOn_14();
  public void OutputTrianglesOn()
    { OutputTrianglesOn_14(); }

  private native void OutputTrianglesOff_15();
  public void OutputTrianglesOff()
    { OutputTrianglesOff_15(); }

  public vtkImageDataGeometryFilter() { super(); }

  public vtkImageDataGeometryFilter(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-20-armv6h.pkg.tar.xz: vtk/vtkImageDataGeometryFilter.java <==
// java wrapper for vtkImageDataGeometryFilter object
//

package vtk;
import vtk.*;

public class vtkImageDataGeometryFilter extends vtkPolyDataAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetExtent_2(int id0[]);
  public void SetExtent(int id0[])
    { SetExtent_2(id0); }

  private native void SetExtent_3(int id0,int id1,int id2,int id3,int id4,int id5);
  public void SetExtent(int id0,int id1,int id2,int id3,int id4,int id5)
    { SetExtent_3(id0,id1,id2,id3,id4,id5); }

  private native void SetThresholdCells_4(int id0);
  public void SetThresholdCells(int id0)
    { SetThresholdCells_4(id0); }

  private native int GetThresholdCells_5();
  public int GetThresholdCells()
    { return GetThresholdCells_5(); }

  private native void ThresholdCellsOn_6();
  public void ThresholdCellsOn()
    { ThresholdCellsOn_6(); }

  private native void ThresholdCellsOff_7();
  public void ThresholdCellsOff()
    { ThresholdCellsOff_7(); }

  private native void SetThresholdValue_8(double id0);
  public void SetThresholdValue(double id0)
    { SetThresholdValue_8(id0); }

  private native double GetThresholdValue_9();
  public double GetThresholdValue()
    { return GetThresholdValue_9(); }

  private native void ThresholdValueOn_10();
  public void ThresholdValueOn()
    { ThresholdValueOn_10(); }

  private native void ThresholdValueOff_11();
  public void ThresholdValueOff()
    { ThresholdValueOff_11(); }

  private native void SetOutputTriangles_12(int id0);
  public void SetOutputTriangles(int id0)
    { SetOutputTriangles_12(id0); }

  private native int GetOutputTriangles_13();
  public int GetOutputTriangles()
    { return GetOutputTriangles_13(); }

  private native void OutputTrianglesOn_14();
  public void OutputTrianglesOn()
    { OutputTrianglesOn_14(); }

  private native void OutputTrianglesOff_15();
  public void OutputTrianglesOff()
    { OutputTrianglesOff_15(); }

  public vtkImageDataGeometryFilter() { super(); }

  public vtkImageDataGeometryFilter(long id) { super(id); }
  public native long   VTKInit();

}
